@@ -12,12 +12,12 @@ test_that("errorGen works", {
 	xy <- data.frame(x = c(0:9), y = rep(1, 10))
 	coordinates(validation.spdf) <- xy
 	
-	m <- matrix(NA, 1, 10)
+	m <- matrix(1, 1, 10)
 	out.ras <- raster::raster(m, xmn = 0, xmx = ncol(m), ymn = 0, ymx = nrow(m))
 	out.ras[] <- validation.data + rnorm(ncell(out.ras), mean = 0.01,
 																			 sd = 0.2)
 	valid.stats <- errorGen(out.ras, validation.spdf, validation.data,
-													plot = TRUE, title = "Validation Plot")
-	valid.stats
+													plot = FALSE, title = "Validation Plot")
+	expect_equal(length(valid.stats), 2)
 	
 })
