@@ -7,15 +7,17 @@ test_that("ipdwInterp works", {
   
 	spdf <- data.frame(rnorm(2))
 	xy <- data.frame(x = c(4, 2), y = c(8, 4))
-	coordinates(spdf) <- xy
-	m <- matrix(NA, 10, 10)
-	costras <- raster(xmn = 0, xmx = ncol(m), ymn = 0, ymx = nrow(m))
-	costras[] <- NA
+	sp::coordinates(spdf) <- xy
+	m <- matrix(NA, 10, 5)
+	costras <- raster::raster(xmn = 0, xmx = ncol(m), ymn = 0, ymx = nrow(m))
+	costras[] <- 1
 	
 	costras[] <- runif(ncell(costras), min = 1, max = 10)
 	for(i in seq_len(nrow(costras))){
 	  costras[i,] <- costras[i,] + i
-	  costras[,i] <- costras[,i] + i
+	}
+	for(i in seq_len(ncol(costras))){
+		costras[,i] <- costras[,i] + i
 	}
 	
 	rstack <- pathdistGen(spdf, costras, 100, progressbar = FALSE)
@@ -36,7 +38,6 @@ test_that("ipdwInterp works", {
 # 	skip_on_appveyor()
 # 	
 # 	m <- matrix(NA, 10, 10)
-# 	browser()
 # 	expect_s4_class(raster::raster(xmn = 0, xmx = 10, ymn = 0, ymx = 10),
 #   "RasterLayer")
 # })
